@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2004-2006 Johan Svedberg <johan@svedberg.com>
+# Copyright (C) 2004-2007 Johan Svedberg <johan@svedberg.com>
 
 # This file is part of ontv.
 
@@ -58,12 +58,14 @@ def main():
             standalone = True
 
     gnome.init(NAME, VERSION)
-    gtk.threads_init()
+    gtk.gdk.threads_init()
+    gtk.window_set_default_icon_list(*GUI.get_icon_list([16,22,24,32,48]))
 
     if standalone:
         window = gtk.Window(gtk.WINDOW_TOPLEVEL)
         window.set_title(NAME)
-        window.set_icon(GUI.icon)
+        window.props.allow_grow = False
+        gtk.window_set_default_icon_list(*GUI.get_icon_list([16,22,24,32,48]))
         window.connect("destroy", gtk.main_quit)
         applet = gnomeapplet.Applet()
         applet_factory(applet, None, debug, True)
