@@ -451,8 +451,6 @@ class PreferencesDialog:
                 self.config.grabber_command = "%s %s %s" % (grabber, \
                                                             "--output", output)
             else:
-                GUI.set_active_from_string(combobox,
-                                           self.config.configured_grabbers[0])
                 assistant = XMLTVAssistant(self.config, self.xmltvfile)
                 assistant.show()
 
